@@ -32,9 +32,9 @@ func (c *config) JWTMiddleware() fiber.Handler {
 	})
 }
 
-func (c *config) JWTGenerate(ctx *fiber.Ctx, user entity.User) (interface{}, error) {
+func (c *config) JWTGenerate(user entity.User) (string, error) {
 	if !c.JWTEnable() {
-		return nil, nil
+		return "", nil
 	}
 
 	switch c.JWTMode() {
@@ -47,18 +47,18 @@ func (c *config) JWTGenerate(ctx *fiber.Ctx, user entity.User) (interface{}, err
 		return j.SignedString(c.JWTKey())
 	}
 
-	return nil, nil
+	return "", nil
 }
 
-func (c *config) JWTParse(ctx *fiber.Ctx) (user entity.User, err error) {
+func (c *config) JWTParse(ctx *fiber.Ctx) (user entity.User) {
 	if !c.JWTEnable() {
-		return entity.Admin, nil
+		return entity.Admin
 	}
 
 	claims := ctx.Locals(c.JWTContextKey()).(*jwtProvider.Token).Claims.(jwtProvider.MapClaims)
 
 	if v := claims["user"]; v != nil {
-		err = mapstructure.Decode(v, &user)
+		_ = mapstructure.Decode(v, &user)
 	}
 
 	return
